// ϡץꥱ ɤȤä줿VC++ ץꥱ ץȤ 
// ᥤ ץ եǤ

#include "stdafx.h"

#using <mscorlib.dll>

using namespace System;

/*****************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   e-mail: bowkenken@users.sourceforge.jp
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: lnl-dos.cpp,v 1.5 2007/03/02 05:19:48 bowkenken Exp $
*****************************************************************/

#include	"../gmain.h"
#include	"../gmain-prot.h"
#include	"../main-dos-prot.h"

/**/

int _tmain(int argc, _TCHAR* argv[] )
{
    // TODO: Υץ ɤȼΥɤ֤Ƥ
	main_dos( argc, (char **)argv );

	return 0;
}
